<template>
  <gree-popup class="lig-popup" position="bottom" get-container="body" v-model="isShow" safe-area-inset-bottom @hide="onHide">
    <gree-radio-list :value="LigStatus" :options="radioLists" @change="onClick"> </gree-radio-list>
  </gree-popup>
</template>

<script>
import { popup, RadioList } from 'gree-ui';
import { types } from '@/store/types';
import { mapState, mapMutations, mapActions } from 'vuex';

export default {
  name: 'LigAutoPopup',
  components: {
    [popup.name]: popup,
    [RadioList.name]: RadioList
  },
  data() {
    return {
      isShow: false
    };
  },
  computed: {
    ...mapState('control', {
      Lig: state => state.dataObject.Lig,
      StHt: state => state.dataObject.StHt || 0,
      LigSen: state => state.dataObject.LigSen || 0,
      LigAutoPopup: state => state.popup.LigAutoPopup
    }),
    LigStatus() {
      return [0, 0, 2, 1][this.Lig * 2 + this.LigSen];
    },
    radioLists() {
      return [
        {
          value: 2,
          text: '自动',
          brief: '根据环境自动开启或关闭面板灯光'
        },
        {
          value: 1,
          text: '常开',
          brief: ''
        },
        {
          value: 0,
          text: '关闭',
          brief: ''
        }
      ];
    }
  },
  watch: {
    LigAutoPopup(val) {
      this.isShow = val;
    }
  },
  methods: {
    ...mapMutations('control', {
      SetPopup: 'SET_POPUP',
      setDataObject: 'SET_DATA_OBJECT'
    }),
    ...mapActions({
      sendData: types.SEND_DATA,
      sendCtrl: types.SEND_CTRL,
      stateMatchineInterFace: 'STATE_MACHINE_INTERFACE'
    }),
    onClick(option) {
      let Lig = 0;
      let LigSen = 0;
      switch (option.value) {
        case 0:
          LigSen = 1;
          break;
        case 1:
          Lig = 1;
          LigSen = 1;
          break;
        case 2:
          Lig = 1;
          break;
        default:
          break;
      }
      this.sendData({
        Lig,
        LigSen,
        StHt: 0
      });
    },
    onHide() {
      this.SetPopup({ LigAutoPopup: false });
    }
  }
};
</script>

<style lang="scss">
.lig-popup {
  width: 100%;
  color: #404657;
  .gree-radio-list {
    .gree-radio-icon {
      .gree-icon.icon-font.checked {
        color: #71acf1;
      }
    }
  }
}
</style>
